@@ -9,7 +9,6 @@ import copy
 import math
 import datetime
 import time as clock
-from typing import Dict, Tuple, Union
 import uuid
 
 import numpy as np
@@ -18,27 +17,27 @@ import logging as log
 import pprint
 
 from multiprocessing import Pool
-from typing import Any, Dict
+from typing import Any, Dict, Tuple, Union
+
+from pymongo.errors import PyMongoError
 
 from vivarium.library.units import units, Quantity
 from vivarium.library.dict_utils import (
     deep_merge,
-    deep_merge_multi_update,
     MULTI_UPDATE_KEY,
 )
 from vivarium.core.emitter import get_emitter
 from vivarium.core.process import (
     Composite,
     Deriver,
-    Factory,
     Process,
     ParallelProcess,
     serialize_dictionary,
 )
 from vivarium.library.topology import (
     get_in, delete_in, assoc_path,
-    without, update_in, inverse_topology,
-    paths_to_dict, dict_to_paths
+    without, inverse_topology,
+    dict_to_paths
 )
 from vivarium.core.registry import (
     divider_registry,
@@ -48,9 +47,11 @@ from vivarium.core.registry import (
 
 pretty = pprint.PrettyPrinter(indent=2)
 
+
 def pp(x):
     pretty.pprint(x)
 
+
 def pf(x):
     return pretty.pformat(x)
 
@@ -62,11 +63,12 @@ Path = Union[Tuple[str, ...], Tuple[()]]
 log.basicConfig(level=os.environ.get("LOGLEVEL", log.WARNING))
 
 
-def starts_with(l, sub):
-    return len(sub) <= len(l) and all(
-        l[i] == el
+def starts_with(a_list, sub):
+    return len(sub) <= len(a_list) and all(
+        a_list[i] == el
         for i, el in enumerate(sub))
 
+
 # Store
 def key_for_value(d, looking):
     found = None
@@ -76,6 +78,7 @@ def key_for_value(d, looking):
             break
     return found
 
+
 def depth(tree, path=()):
     '''
     Create a mapping of every path in the tree to the node living at
@@ -164,6 +167,7 @@ class Store(object):
         self.sources = {}
         self.leaf = False
         self.serializer = None
+        self.topology = {}
 
         self.apply_config(config, source)
 
@@ -240,7 +244,6 @@ class Store(object):
           map the process perspective to the actual tree structure.
         '''
 
-
         if '*' in config:
             self.apply_subschema_config(config['*'])
             config = without(config, '*')
@@ -286,7 +289,7 @@ class Store(object):
                 if isinstance(self.default, Quantity):
                     self.units = self.units or self.default.units
                     self.serializer = self.serializer or serializer_registry.access('units')
-                elif isinstance(self.default, list) and (len(self.default) > 0) and isinstance(self.default[0], Quantity):
+                elif isinstance(self.default, list) and len(self.default) > 0 and isinstance(self.default[0], Quantity):
                     self.units = self.units or self.default[0].units
                     self.serializer = self.serializer or serializer_registry.access('units')
                 elif isinstance(self.default, np.ndarray):
@@ -694,7 +697,7 @@ class Store(object):
 
                     # find the process updates
                     source_process_paths = source_node.depth(
-                        filter=lambda x: isinstance(x.value, Process))
+                        filter_function=lambda x: isinstance(x.value, Process))
                     source_processes = [
                         (target_path + source_path, source_process.value)
                         for source_path, source_process in source_process_paths]
@@ -930,7 +933,7 @@ class Store(object):
                 key: state.inner_value(key)
                 for key in keys}
 
-    def depth(self, path=(), filter=None):
+    def depth(self, path=(), filter_function=None):
         '''
         Create a mapping of every path in the tree to the node living at
         that path in the tree. An optional `filter` argument is a function
@@ -938,12 +941,12 @@ class Store(object):
         * filter=lambda x: isinstance(x.value, Process)
         '''
         base = []
-        if filter is None or filter(self):
+        if filter_function is None or filter_function(self):
             base += [(path, self)]
 
         for key, child in self.inner.items():
             down = tuple(path + (key,))
-            base += child.depth(down, filter)
+            base += child.depth(down, filter_function)
         return base
 
     def apply_subschema_path(self, path):
@@ -1350,7 +1353,8 @@ class Experiment(object):
             'data': data}
         try:
             self.emitter.emit(emit_config)
-        except:
+        except PyMongoError:
+            log.exception("emitter.emit", exc_info=True, stack_info=True)
             # TODO -- handle large parameter sets in self.processes to meet mongoDB limit
             del emit_config['data']['processes']
             del emit_config['data']['state']
@@ -1423,6 +1427,10 @@ class Experiment(object):
             deriver = self.deriver_paths.get(path)
             if deriver:
                 # timestep shouldn't influence derivers
+                # TODO(jerry): Do something cleaner than having
+                #  generate_paths() add a schema attribute to the Deriver.
+                #  PyCharm's type check reports:
+                #    Type Process doesn't have expected attribute 'schema'
                 update, process_topology, state = self.process_update(
                     path, deriver, 0)
                 self.apply_update(update.get(), process_topology, state)
@@ -1484,6 +1492,12 @@ class Experiment(object):
                     timestep = future - process_time
 
                     # calculate the update for this process
+                    # TODO(jerry): Do something cleaner than having
+                    #  generate_paths() add a schema attribute to the Process.
+                    #  PyCharm's type check reports:
+                    #    Type Process doesn't have expected attribute 'schema'
+                    # TODO(chris): Is there any reason to generate a process's
+                    #  schema dynamically like this?
                     update = self.process_update(path, process, timestep)
 
                     # store the update to apply at its projected time
@@ -1558,6 +1572,7 @@ class Experiment(object):
         else:
             print('Completed in {:.2f} seconds'.format(clock_finish))
 
+
 def print_progress_bar(
         iteration,
         total,
@@ -1580,6 +1595,7 @@ def print_progress_bar(
     if iteration == total:
         print()
 
+
 # Tests
 quark_colors = ['green', 'red', 'blue']
 quark_spins = ['up', 'down']
@@ -1925,6 +1941,7 @@ def test_2_store_1_port():
     """
     class OnePort(Process):
         name = 'one_port'
+
         def ports_schema(self):
             return {
                 'A': {
@@ -1936,6 +1953,7 @@ def test_2_store_1_port():
                         '_emit': True}
                 }
             }
+
         def next_update(self, timestep, states):
             return {
                 'A': {
@@ -1945,9 +1963,11 @@ def test_2_store_1_port():
     class SplitPort(Composite):
         """splits OnePort's ports into two stores"""
         name = 'split_port_generator'
+
         def generate_processes(self, config):
             return {
                 'one_port': OnePort({})}
+
         def generate_topology(self, config):
             return {
                 'one_port': {
@@ -1976,6 +1996,7 @@ def test_2_store_1_port():
 def test_multi_port_merge():
     class MultiPort(Process):
         name = 'multi_port'
+
         def ports_schema(self):
             return {
                 'A': {
@@ -1990,6 +2011,7 @@ def test_multi_port_merge():
                     'a': {
                         '_default': 0,
                         '_emit': True}}}
+
         def next_update(self, timestep, states):
             return {
                 'A': {'a': 1},
@@ -1999,9 +2021,11 @@ def test_multi_port_merge():
     class MergePort(Composite):
         """combines both of MultiPort's ports into one store"""
         name = 'multi_port_generator'
+
         def generate_processes(self, config):
             return {
                 'multi_port': MultiPort({})}
+
         def generate_topology(self, config):
             return {
                 'multi_port': {
@@ -2072,15 +2096,14 @@ def test_complex_topology():
                     'u': 3,
                     'v': states['E']['u']}}
 
-
     class PoQo(Composite):
         def generate_processes(self, config=None):
-            P = Po(config)
-            Q = Qo(config)
+            p = Po(config)
+            q = Qo(config)
 
             return {
-                'po': P,
-                'qo': Q}
+                'po': p,
+                'qo': q}
 
         def generate_topology(self, config=None):
             return {
@@ -2098,7 +2121,6 @@ def test_complex_topology():
                         'u': ('aaa', 'u'),
                         'v': ('bbb', 'e')}}}
 
-
     initial_state = {
         'aaa': {
             'a': 2,
@@ -2111,8 +2133,8 @@ def test_complex_topology():
         'ddd': {
             'z': 333}}
 
-    PQ = PoQo({})
-    pq_config = PQ.generate()
+    pq = PoQo({})
+    pq_config = pq.generate()
     pq_config['initial_state'] = initial_state
 
     experiment = Experiment(pq_config)
@@ -2183,6 +2205,7 @@ def test_sine():
 def test_units():
     class UnitsMicrometer(Process):
         name = 'units_micrometer'
+
         def ports_schema(self):
             return {
                 'A': {
@@ -2195,26 +2218,33 @@ def test_units():
                     }
                 }
             }
+
         def next_update(self, timestep, states):
             return {
                 'A': {'a': 1 * units.um}}
+
     class UnitsMillimeter(Process):
         name = 'units_millimeter'
+
         def ports_schema(self):
             return {
                 'A': {
                     'a': {
                         # '_default': 0 * units.mm,
                         '_emit': True}}}
+
         def next_update(self, timestep, states):
             return {
                 'A': {'a': 1 * units.mm}}
+
     class MultiUnits(Composite):
         name = 'multi_units_generator'
+
         def generate_processes(self, config):
             return {
                 'units_micrometer': UnitsMicrometer({}),
                 'units_millimeter': UnitsMillimeter({})}
+
         def generate_topology(self, config):
             return {
                 'units_micrometer': {'A': ('aaa',)},
